@@ -40,6 +40,7 @@ class AFPEntitiesProcessor(ProcessorBase):
             with add_logging_context(docid=document.identifier):
                 if document.annotations:
                     document.altTexts = document.altTexts or []
+                    mark_whitelisted(document)
                     ann_groups = group_annotations(document, by_lexicon)
                     # 1. Compute document fingerprint
                     fingerprints = compute_fingerprint(ann_groups)
@@ -78,6 +79,17 @@ def compute_fingerprint(ann_groups):
     return fingerprints
 
 
+def mark_whitelisted(document):
+    for a in document.annotations:
+        if is_whitelist(
+            a
+        ):  # Consider whitelisted terms as entities coming from the model
+            if a.label.startswith("AFP"):
+                a.label = a.label[3:]
+                a.labelName = a.labelName[3:]
+                a.terms = None
+
+
 def consolidate_and_link(ann_groups, kill_label):
     conso_anns = []
     for model_r in ann_groups[""].ranges():
@@ -149,6 +161,16 @@ def has_knowledge(a: Annotation):
     return a.terms is not None
 
 
+def is_whitelist(a: Annotation):
+    if has_knowledge(a):
+        for term in a.terms:
+            props = term.properties or {}
+            status = props.get("status", "")
+            if "w" in status.lower():
+                return True
+    return False
+
+
 def by_lexicon(a: Annotation):
     if a.terms:
         lex = a.terms[0].lexicon.split("_")
