@@ -76,3 +76,47 @@ def test_afp_entities_linker(original_doc):
     assert len(conso_groups["wikidata"]) == 10
     assert len(conso_groups["location+wikidata"]) == 1
     assert len(conso_groups["organization+wikidata"]) == 2
+
+
+def test_afp_entities_whitelist():
+    testdir = Path(__file__).parent
+    source = Path(testdir, "data/afp_ner_fr-document-test-whitelist.json")
+    with source.open("r") as fin:
+        doc = json.load(fin)
+        original_doc = Document(**doc)
+    # linker
+    doc = original_doc.copy(deep=True)
+    processor = AFPEntitiesProcessor()
+    parameters = AFPEntitiesParameters()
+    docs = processor.process([doc], parameters)
+    conso: Document = docs[0]
+    assert conso.altTexts == HasLen(1)
+    altText = conso.altTexts[0]
+    FINGERPRINT = re.compile(r"(Q\d+[ ]?)+")
+    assert altText.dict() == IsPartialDict(
+        name="fingerprint", text=IsStr(regex=FINGERPRINT)
+    )
+    assert len(conso.annotations) < len(original_doc.annotations)
+    conso_groups = group_annotations(conso, by_linking)
+    assert len(conso_groups["candidate"]) == 7
+    assert len(conso_groups["person"]) == 2
+    persons = [r.value.dict() for r in conso_groups["person"].ranges()]
+    assert persons == IsList(
+        IsPartialDict(
+            label="AFPPerson",
+            text="reine Maxima",
+            terms=IsList(
+                IsPartialDict(identifier=IsStr(regex=r"^afpperson.*")), length=1
+            ),
+        ),
+        IsPartialDict(
+            label="AFPPerson",
+            text="Letizia",
+            terms=IsList(
+                IsPartialDict(identifier=IsStr(regex=r"^afpperson.*")), length=1
+            ),
+        ),
+        length=2,
+    )
+    assert len(conso_groups["wikidata"]) == 1
+    assert len(conso_groups["location"]) == 2
